
# q-expansion of newform 90.16.c.e, downloaded from the LMFDB on 11 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 90
weight = 16
poly_data = [25064779091755865960773413038603064397578710236940210149877760000, 0, 4141418827690700793980368732720094517394846053064084563300, 0, 243655669397438624319289580389876593903711764861841, 0, 6306932914279579973235286083160651948918938, 0, 78505143006386219920881563766722959, 0, 475511948368963765554364384, 0, 1419072122452249599, 0, 1960198978, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 11950596605244353095595734457478562432660321913879259200055902265555606625688660603028234720552700058749136654288980760671200, 0, 1316937484657583813752104701896208968301818412750970140341046804565238770933636565421544908569346456954333348713912116, 0, 46104446236201600888705761327809180421331319100363211408322783799567884253294847867794707952027790176034626795, 0, 682399977637759564447557770231260120912929420364165845740043981973619915033050464792866332566819888367, 0, 4521612326625864676291698018394567354448230840709267453207248722020026102288753309071623778910, 0, 14175936538784019813157354075672123452056762967227043768356515506164304341465097049218, 0, 20130517278561392353835422600827921584116334523514151609692758903665018957095, 0, 10441077762362482331706959734870391215689845328990660520014894608299], 70815475608670982973709443162376230906916670137033066096724438674650877040185280949257689151564709207905060533863630582000], [[0, 31123964538620230629794928323668240351674477226274580917306158081103321919408581960657655718813564016085307079230763272504747945458551623528438515874953315543136800, 0, 84631473145413127168330348990622031375856403509333456685218110219715519709454269735722738021997981240344034814943217754542043723776952692269051422717354972, 0, -33519595507837676187557532309573861175642068703351222287064668073331473117168464623175325253459857399539636703767543496797194263651821415170321593103, 0, -706760196730853339537155722272768489532654111902892774771550394543316465323279356863836778467797713750455372951325543296005977392486794363793, 0, -5277999194660015677821542665323192489183018648701181853706543159774098521427067587090549750567664561811790279809297195594425842694654, 0, -17467741363312402521055906962917172696516634893894092155095353455516465786863822745571477706137472037931162090700053791629870, 0, -25493713039697946082144125825927955070493523090785689989765117139763019165814554874075549015319616728006393951802643, 0, -13428493412895742185708060579122886830298009207294290905997969574534409318549322141543592313096328062471709], 32868250164662935380506669684713857742633716119441630538911956495713329696209178756846644560876773938291103752020596780367154807640714219712303962821482469440000], [[-59619577134436790693104916769960544898514247975374985730983596543792710622182173180978968922348992322318458984658536672703949814352054791785210414231339664905988791040000, -3622106666579263695528243644154753675479431044195807996273939571345675721913922779680511040756338377406383549009165758874821154963170141268542568473008861673805118000, -5567274727231118802846291611519194850051415306158587226753198395897950448375447433637130584798724228930232991145124106122046944827855189790739703485411337006693200, -331056841820342555302614706464883378135405306797909917043669195124143414970157052634489037448525414769987489601451294469973276746248854088288157032077598129240, -141505539841117704835931230260176600132984612568071991590721498524728435268477315599733061119622291249334980336360904102391414198394417103689231770500965564, -7953504615419205093200001614393115758463763949962920108095052428086015468706971243150146514323844724754127443726251644021770875701588387345122792663879, -1478339516037583605717202545936637323463008599692680914135590086618742039906512946054957778542949214135276487341005099089739915970656451970203277946, -75177669990777509652312422894420826274314434104746260731411370021686638945294520862037276884499656845024442994460335271447661421994311821753061, -7632462295080716728229478736977854890734672690517418453268392183317462269944084379422564823905295563707270010648036025524762030978633369552, -340935499167015944278765329560768537598716178513576574082238781657966737090906853459767925321472848886238876460852350108569462679110622, -20266938821277398828361656261005187893622713370031371694391519434760317213887952004251096818837198405305264120050219919614956156028, -785343413514410468083320399580763976030088240338770132595706229657355488752984602071598175148093068501302167040048256928427978, -25923182543081729331919195257595677399948334860071088914081153811352068019492222373171118528424193712437104984985950667684, -883439750260428840850598002496171333153006305545721005820121981341908845740118048570907668412852538411024362886840299, -12571836306907351854554739423537173391807340584400969733882839207576739596361455310180321946270775663191651522026, -384896510447089158245500903509803831422563353798759682664387542296859166282258811938351359438099708203748921], 92031100461056219065418675117198801679374405134436565508953478187997323149385700519170604770454967027215090505657670985028033461393999815194451095900150914432000], [[-12445496065355835575119326688019116076086716472536046735015035541983965700472079099875235044567143298158555017651939369219200541068387326140667985240168556544632064000, -6128162444598620971363360337054620470641088640568228408032422934486986284699913977944054256941702920807129665918436744486455628696788086061022118945315797834840000, -2948709968152270015779431976363898283166887128524676247858908983333726067996219700265408901309128348365744940052526182388519702123158528090569641494049252057700, 592755485994793759016983682204379286602999620938794168923126735827133451845786352382924540204641985509751538461457264079241535363399518045355705878181557800, -134300414584323806220932601060782264274345433075180764757894793435933886069017215190924316061207907045897983873368099029025689916548970154749495747389229, 39745686782235331754870861849675940430326848903285221687047146160287455399028126965975683983154172537242746172819566487026381363477385402458161297806, -2123969980842091235774607370496951102138554078654854827538283205121158615356906198694697527333162111965450627017210725551090923060131461042447581, 693750910359927926399998080310439379624053600377204650959695093112722161510467654471748305859072512454533309577053974829943344644730221786834, -14382864086776744916011295832666591468751752295877784132824208313613977055467347696196127107127545725252769624941750641916229434869737122, 4856380041878492478318835432579532619632983965982341601487036786654565173071795371485206465673643611133240956744505880550275943186908, -45486235871709159892265085040569128987276130227438050194902596280611047986737210923283728843108186938592603779746677451989251358, 15571839976874755454079015696355619604763487405535286558757587718007098528135831766895001079759844058547612947740438876717212, -64841217333360637617266442378807480876671191513238730979541475092266411216592363642092428831305647719457623532413712449, 22343673331600413796885910270973681744567522153067144775365235242725112180921690089707765311966049543423956157350486, -33694542447066482475248330769112359809853806547901865509349415826374667268329090049653603855525316394246576561, 11652054002220806279192835756949206722734132661761990346759750781345246977348841099775523774232901474510954], 1437985944704003422897166798706231276240225080225571336077398096687458174209151570612040699538358859800235789150901109141063022834281247112413298373439858038000], [[0, -34868785155618882180722220477455006655785253632444456901421745892978751851881676152024349002669001605599083310218714465275690129316132920210091825496207901044867200, 0, -10284482773343218602551820066370536619792505859707976391658398099761240404467467348165964571037226381575571977473406644892383350094386180510317671576739795588, 0, -517016643979440354327526319825096478726509045563190315009504607405623013499290920885681708928190923414981813459768196344427359160599782598530237705613, 0, -8502961745429738789412248280253973252149851355478653623849236049993454520087649580411632548815171802618547652376765622524435685386543118038453, 0, -58233174500498255289307426625922855483782929466687491214395946477084784475551799183763429988268910489473730633059095115725466326020834, 0, -184759660040163152444848374697825737625490657681847956045881610834571951715902780112425228643797228461096965411758731009450670, 0, -263621557919905171422807474602447612204446469256625027981359380422349960713387502699615821417747452655888781141721953, 0, -137024838929847918120393333121449838794998583925966606384072338364746599200600196033748430581756341257443689], 3486026532615765873690101330196924306036909285395324451096722658636262240507034110574644120092991175273298882790063294887425509901287871787668602117429958880000], [[530164043688594347922513568939807359889222130487223473624613840662226118649869736916087283463221286672167119133613303390359778625555834553690342233383706500064407840000000, 58022953344458928941988316473348633383874146002874697742783269953810315490233041227161232979013979053429871899081541110948846615423081498598717313808263494921656714400, 94994327782446005906401624525167539660919401440638043831919197130243316186504245045036732526757229240063335013757348219759817995075653809770080242166895144349269900, 1407512195659759203448867774561730576662754475247580584550394978386594129806099222321104322801180845972599394473774548270098458471420820360091413812298883710276, 4309996587606814167136002336435512317513490786107003757920312970488070160601091230838731572899320362120297803452885111830812630073666835979579382364087211535, 5793478402545799433237468541053460541303379044508246686839030874902287597561081285111384908913969489465294416866834621787655712917064316010904748984491, 67491011688633147146276686685132779627166885097587618970428585018310769386151911746078656970567130599842516464701146377385906878304711343208873505715, -161540777123822061071934751888471786441131990981339942436022564408126527134415581588412259332641831322182050161592967768779271540682622902606559, 450027805109279745372241866970879968569697544094928783903091754356045720198452921191921752146294125376778783289326103279020551047802376538630, -1734649347463533486685714922302354363392101691624203266636791404081412089962968248212685352865549050556853608199822631850251876247033562, 1405682349225128361336497391240434734604496189140894592678956073517792427337525932286646631319772143409592885689021752515691290911170, -6417414727945021148858723411078254069013145519484163531531883953101109207503749581207663633695345536149025373428837077684523330, 1987531713446022316423629109889064225228823905333353122498796765133323193319770932557546228768016756556547870361649049771835, -9822112689034219584598324284690506064716859748417379808342292835289392769037087729168560719109052896327839325535946129, 1027343699515483738921720351346123785790461120868693459312276102933328503371692646304533991394059860580474886171215, -5301695540391554910749272639760698973279406454209596395126158780254487343332831151706890259730695471699691587], 76692583717546849221182229264332334732812004278697137924127898489997769291154750432642170642045805856012575421381392487523361217828333179328709246583459095360000], [[-142880528220049511586608164127386638076740848347259333517519277800360636515840969233604806205542108802469039428287338936521939664941016213895956822766420071786713607030912000, 325581914428117433344329726567931572848039980035833836661767484142359947927724832938037364004473482832886966153077441903383969472871508610578324987463778292464465676000, -16851737994494531469577167355931902569829040352085783797735975350774193891196168010209674942327728622830991107313581397831495271080464481311756148724953106654990159380, 29750189437644635726171275465866265694213427764750327616322990220248462068519470497663671126397666791933694186198405541869016228770483747198159203915538130485680, -649158293618617017569204591551304672035087107082539693307125751779016937718147442918471525680664109853247591932666870493120128849986880321974288619270321041421, 714242597076781824950335246290167939343695010548699037803887014597550199516168558823859110309017859367209444839640226157698462993077169363743792866368710, -10307058881104667658340407817309198121157782168519527001827971519526383016032929202592996817978170915313473259397097874851190719249805308080037181679594, 6742710740085379725783646007470216949073326535383821375039271964887963185932221127069647295695543911179615086395146760669373205180072102817042450, -70958173683751821998150351318419692286595467091747803509696686099829595908311064060221725771433185599037938677353305514956787369840784192413878, 30529943540557912714567498317622682526814022909775901717769915217065919297246692525836977658179049775883479111221466387069771716575316780, -227441626388307460945853225571671670883685158335728959791957370515529054821710757987600114573648831964605803613841854273302053377641052, 70197305863646711098859274511733681952986124280154609380977986621828898349697576659426271382239534040179293851733081707815845860, -327149998987242892246396201016297658944445065086498307658157904629070018242831182588608738892330613403232109780459973503862901, 78822840152766351121577519842404005342052122356938213051533593810274729524158574647956418738336387036591090586906510510, -171026708724059062515981102293360544557931080002239494973434575499579294586751588674827608020718701382481777483415774, 34284496469779385800556467888043455863283816159546841463380860775791379844670606116800546457601100704220994010], 345116626728960821495320031689495506297654019254137120658575543204989961810196376946889767889206126352056589396216266193855125480227499306979191609625565929120000], [[-2922722813006106850758988894814751772421244831442566571076271554433397940168910721880224215308425989858140629851611572235105346735358502869897410296328327597738399457446144000, -2441893478608310485743416677931343671927807622693167266606319493730467528532545405409080846438093762041915642809348491160761909223237300586736759275628838569067635066000, -320208841240473337987961353149113273785673809349236363445567235038847878373188947576183039071894188098528094936113520381642843993773684546309903789105957116687989710560, -223129629805633781821360569430852224016455926081846140330822943604786640176667076178151843608266045263600219244911770918333948764235193326896749381435924957295880, -11104883917486638785779542469047365967204498513872247684761789439389480767139004455317595112082365288105493731891484441877144479359893341341827425624718698507872, -5356931822240931303801633268533774722143287132325811624380914588333783010133225537826061475601928814244118123804139012025899966435226326335029679245863925, -162825658401974115694818921241163446869969543619819211864541575074314017912987087676293528598302328401579171329950530009535741083290512193574892207078858, -50571993376289247667871950202671459790593875624953184747850807689307140631573393149487619547995823991338012061042620948860364490479070482637870735, -1069141536200673014653742461338565827943408509416844413234397311569825663438412710075229694939908484574238048659374345970135732201653112084408296, -228985594510218168378579193192373439369467345620208262165390905208862329517988402821316056409253838077974523317750658268930536440353778650, -3325725179747625320762673642055553615295597724040212617710186657399797812940922399782123451384640096758558714286192833098300020749788764, -526514336931111064029204527513040834353804633340469191968237440667097673025451184769055432822588565453125982543846060052600463390, -4696279236277800045431243286680960772044826742967414240810192573891421433415882287741423078636821231897504189934326588298916232, -591220353815081365165758277416762283968370806615763503420236052470667404759221599125632088496010070018747543835578051425, -2426328696225524243528768273034435355819597461899464563659654433628199085112017192247892372909531242134409648414217418, -257159165628378153392854838690885839614967684459625705973671742820644344915081880658693460995710246212665769995], 1380466506915843285981280126757982025190616077016548482634302172819959847240785507787559071556824505408226357584865064775420501920909997227916766438502263716480000], [[2265745092824898804411324670947756099657296969826536834074409603868727923420258721503189519817391029035115201728549031252478889434893501862499217179227867603709116368973568000, 1573752694526476625254387350208477812513055069062713013223108503118222118257570273237782852838278183274919457497855784446090359100115906978259417628126766790720106586000, 428257402307686684379723798561269513481880581540637559267564816332451436086432881364806039338351151843778153403733194740489051560528272865228320893055014992444787636320, 143804348700712123551773177353489465658167366299095088576363014891919207094671281372846881031961718682703735677512634418193444283398077262129805776512860552409480, 24496944469252234638867439481019077128578264467962802304805287505309222781551264701823763904958114980708594321050591192444711184869346646077852588228576041568624, 3452584481143026748398389735380034022734965912757464432508581159679399848122006305354752243536000839905019037583331251187134715752747357650249518930476965, 471912943429004583387905394677890795782697248145840112281280148263328442094546503129615513723269707573673320427806077961964459964985626307990754528767286, 32595865604458634331101174573803768386515475822795059574562796989999016767972096001209266306885692648168102265532950237315543814341624105819230495, 3506325356410832490682417384312453614867038029245131027623784679264353987059447899170552443222694395847075374417369904550802757172642637141149432, 147601792951487262524593746505921807080262414652509855670315240845667704161699113092520713248538944699214392310732508879163808038923341370, 11624782196071252934687730643806530901046326510127172571630415962923842673867553829162646220550465272423396576976109722232456280632545188, 339413635838081783199606378615186268362931505231549224581369585684569771833509273206207769018728635084064608688152368149042526270, 16992893572133874724838661546392654945048864672402377573796638740244978076184170015563382420467664353028912655436337309184732744, 381156920525927713518689900766970920130844850833866683372770732692886614902884838106972166416412150572676274093905283665, 8959599431128268509493005756851564953790886688831680814033052221444533846400242721910186215647209210581291148062636406, 165801687322387150961187803070929745687115010068899182066830212757757988209433157101063637278645953484098625755], 690233253457921642990640063378991012595308038508274241317151086409979923620392753893779535778412252704113178792432532387710250960454998613958383219251131858240000], [[63467636768222027462056587391962972591503766473951548556740792996723922051165962440543925361054814594285258639154549535102254781146458410129919289187352087881490197760000, 46846824255424035807980432537246566348961152018433141092828039790144984073421942895727063207152764286975972978903702198884179354011289510098421707013658647018631605600, -231736042781093507063742215135089579728556726126661434822485354343970888657862629542232103138424356295140377557355902254114340424261040977639638474595106322171581300, -4942981629405024020934692172356188394709945747877508835179548450740972483478299869700783298659547050946098556629711885100643666038746324845431256745691969107276, -10555452848260064037871612884092081272072237161202889352953385903215241207670852644522200253661616574636884063043548311085389890456403400367007678416483038385, -326226007825655549267580418792130500843958987737787331872052655199838542995330610562035372481132554475720876476257709886985466107066154300234249225863221, -166973015801737778145611993225106383194831229966100355687167016541348513890209305543726044792697320530345205226858777921009739927120096551357093461965, -5678008468029396853489542317120577429364282958255257956940046972223587293879094730742055613211266207692906571078562773326759832450954701616074411, -1131100583800767082160680259671068563779241381982525790785227015411071408374027127015589313520189520934244758538761996243029079236818190967930, -39703108055539275334462445624573726794285085116695824937829175824716027136607537501673874677579215457907596652899652399164237210236685578, -3578374370508147156813761551567384770171375927670976541341124007748533403932759064179599316119366989127531464363030009939787678577470, -127234499006277415842636974967610771142995502773165669912235447804235369804437231875405402448685618786071295167137344300000431130, -5102636814047471371843959036892521702171412260047616571448790650362461683279721332977789235216778403238563059390520768055685, -182508698284635615961165604719652614090426145742444147762399996639884451796215125748116559376520023176462464833566292001, -2652294851910474517630372422517487356203315725893331198253763818410357149847733043230716147949125840693121567497265, -95159099674561974532185221440794055984718348521289618994543396547379378412175298105307060023975928635622399983], 230077751152640547663546687792997004198436012836091413772383695469993307873464251297926511926137417568037726264144177462570083653484999537986127739750377286080000], [[-6617773061922483766934645761465620483735081525266623416139179216360990879062221223088665550380738147777348947297097570670138429393078081888158355979678702804564755805440000, 502867122387979151930796310162887749087479248715416685306359657031476208594164772200538213450644105918008662757906361267651666464500140682421522129017803160508747485200, -617967494722654187115938368878630628355707098983603182169605021944672499769674665133721494912658389411255862017108775779547210875891926066772107086880658407742945200, 45950153328408126585482572712029978315832806443560867734339265501453901695214043446168324871447310711799993807388159361546682859832034081732502504415495383976136, -15707114922364065236788366558879602614761291995055991066570086336244856314800982031570369784278074328676182817336060355365446976021780298509504726525607177604, 1103200382909863081133126660164327407462512482265014005308563127379100663901472992537812881177681141747840134535732808981267076789851618816386427019828301, -164095686280171780234609482598966742904393954565887581469050499614680366429622937012100313418267362769015690094851565998961130672742866168692563852006, 10415109355220959572183639732111975263216032861409621992495807017948174682095856713345673017137163425647700184186365530857863543783791343814586391, -847203314753959556833472139804541892871548668647433448312791532348238311963793366115904695453487807571506971181931998833248585438628304020272, 47160860898711697452830899956717762024288333838095958729407136168404332851961307978102282983136659011139860169393541054220385138787198218, -2249630209161791269948143844971575856192121184073482258077458657258395210741562672471871746890929022988884317325574411077260133319108, 108444241040279854678174187100931222774881279629448918924030313052048956560102175362097479265110085364630405176929405038233804590, -2877473262282071955843030673593120191394265169467890869463008073060079550163636683421994156655085502080518653333440524112924, 121777829764057988396554047493337142126286186545335584707327698419501116334804792019410048372853424157393606218662971481, -1395473830066716055855576076012626246490614804868507640460995152041018095196121539430015736036056098614273318944886, 52971419167463987311552971352216383248683790307120179925391898733316305648145411379492097636894448075348149683], 92031100461056219065418675117198801679374405134436565508953478187997323149385700519170604770454967027215090505657670985028033461393999815194451095900150914432000], [[9292637062132357229422430593720940003478081632826914895477893204681361056352485727906842166610133662625054413180114729017003070664395870185032095645992522219991941120000, 42859049445894660914485989190766060348001550828875063520262709750745323498649774678234590358689907775363700303211774169382231649509520385970229894013753071184992401600, 2201703442887028278448642542351710718097942389298424931734652040889182130770510709531505312977482500113089555239219549516761377585291700974291998982223441536416000, 2846807603654146209762858880502393883412118224183378499476437453956177955129087101751505179529441664496619103281834806274296955104443131989800836493037005423364, 100277642889628441978296342125384090658177923362801637685894779098830634931532854009223489325701903927603827958781513941672515137689897715546290158050624320, 102645412821202728032924082541850760439932142618665600746497456992082836124881370529732719018292865885713132211195072322721609352913178309715977569296009, 1585897585695428122711706836637723489596787045395624937895251459823798432799823295025374153742094376934203134839517341744814555884898157578360860480, 1529894201613405277434884989923196269784617773322008275477034183392974502100818995557629829729544802084759578229894418054962306155058406225466189, 10739205184793302870621767555057721630001308380922078819175408874165102868082286279826441573321900808188734653289840479297451311369403717760, 10106764941085265426584872122895852836856224442277606835027283108456879691750313517292664674118097543535270707363067234289576900601635562, 33963056117542839386224596830291616310499510569820410812193938556189582496763784156051850869520779580815810822210852497485307680640, 31551750410434486460905887844192634200593211148356592170031131877041663667604028552800259723985157699612067080872395011964515150, 48414775608909276087558943642842919054581156329884919131390968068892253708388964852762346860708216963861692237535571961920, 44658265863187886391020922011731982942374443900507384193889885767842451069013689165566961816292656467727735879692877629, 25158591693809640248185420307603895324690842222433392913647563817026418227019053903741357545458902907704110498880, 23109068785138960626183925071092071857785654780120098834909941413192347263296414987720683305445812948045676497], 38346291858773424610591114632166167366406002139348568962063949244998884645577375216321085321022902928006287710690696243761680608914166589664354623291729547680000], [[-6869913828076421237465868331786552073999867492839897797728299619175149066660587663131129744601063100583522369743870531808998698669749804029648727852573043212636899328000, 2527549023409840580762220932734792288385486370390644260377382368082446602109701388394332717078187960408996940776844318622398886037951201190638839676376804221206362400, -1627687902420053048710246450952871852308121694945621288818117758800216789533913274546505713522638848297891206908994452678462875571983507505994442104715187135850400, -266146878037685495929787002070496274617774825005145121874357304422093795064878465755700253177833595377051097474437456831782002148869422753165239593384359379204, -74133828850546741033954795785551809879438679057499782146357925976635505110097502785390222465786764689335687098099190664022180833935031525421721652558854408, -17571430509886564892869243382487804284556933827748320759787668803295459706944421628394879147678850294887972828496792981710238490992305910395064010265367, -1172431429424834362147583268514317008380481851417479864801132329226879555677012221679473035087905485804928746113500320504202189529192566495431064712, -305853086464131737650439049923167462644847434185667434206542548952696313099426553705296383575589901583377735079860901920742576559091731799955081, -7939340975900763193638235299631958490750967267324536841318962989114915334617975928300262163134405240339528832967846354337758648048094891344, -2138712264398944520542087475138368266171295686219180764490246678302826507886174853315738648367818685855009416662873554117362641648872206, -25108402201183456260530326942394159200976423885545803707586233146897298488678940429652618321395719190103117286420165953498066749616, -6853910120096703625780007683226897374058425913422549733237731823478564880096805872349960139789447833963812465952816240227901886, -35792351968015071964731076193101729443922497715307779500706894250931058991558984730435020714880717541140608189892369271848, -9831509661279099758429878920614713736072795262938581029435269568762509122892215276070550016653552878357887600830399227, -18599387430780698326337078584550022615039301214441829761160877536158816332117657707408789328249974649624110261672, -5126120739104651017778433995059384403972805368018311639006382563020929780622435557708629504664665564143605429], 5751943778816013691588667194824925104960900320902285344309592386749832696836606282448162798153435439200943156603604436564252091337124988449653193493759432152000], [[1699157948331448534753490127943875529607656067298187093333032501498092252732191935657900614286946281186076081062768295172062569709033561565878496805593180449820680544640000, -97682612450566423297667279197744954359944332381515400377869683631991509341203571562504894536304705837791196557606829657580466254363165615908897436771271343392701259464600, 158667329726086885881119310928297053226465336225519735962466154283091587778700251858658221666763640524511640247636037024478337927593872909036081549334223104690756200, -8810748612968348493986142066764327001135056228878670648992326181215987337317606770869958172725376785038801239691148059546261228841967501377163209887922818069946730, 4032907885471854587824040062415033103790061458190051760335562707954760405151603494592392241909235300606046939586285766918155304654240887455143105459277518574, -204374556682890006572416522293805201694309289839858525404804020834571256181911018073682746620647562595131923350117957356286332261797336168508517800507771961, 42132676207071132762940272559194163718695745091241406052864317468634148137335618962566296688474052602855379889218645324057587605163708881150793421461, -1822031547988008883931264533589156668137296228415559578999486061268187317936311796412618794740326853190805672580939696788738327614124330477495289874, 217525175409800426754540144003868864385938171679746425918149177224547674693406404813543097481300923565657195303469026727455717882891051032232, -7821686762754717540457641254344809973370449114639676374791437749859801432426588644353531655710129537912644056709390147133442551143211277598, 577607756406405866608307203438647854968247331045894093290158303890669040595806632121156259336860154551200027421431267709026250446798, -17264158014621208532664956149416990037802201791313877642921834366694690151062594894406756367447180968409021304286358481249423680042, 738810702477829285959697064841476805898527543512026034051312883623533938555528337635376878060089520804457492072099594028994, -18818786330639913139394490252695118416820179353669665456550933118977452092243698486218236075511645949814026231902992466041, 358297334746859527854810073570809441666509206655427637415660917415937078496301476340139175468717106400962068377741, -8011274608751097302497684336683021347777978254679684025167727088868514886235202676336382772936394334580124681154], 69023325345792164299064006337899101259530803850827424131715108640997992362039275389377953577841225270411317879243253238771025096045499861395838321925113185824000], [[4829185747889380046141498258366804136779654086005373844209671320047209560396756027659296482710268378107795177757341470489019934962516438134602043552738512857385092074240000, 5458202111426487565393594553395576415721910251774864056125804161940077762817274003170602942267370988738230963634161038987488794256854035950913022058562623023419421898334000, 450949252905720623030549620533054782854164639798845565367009070067733986318411242124607577368696662543348872282755052595885802531056270373049915982318318297542149200, 582074412290524796758840571652004016571298016314496018984121524394925571902448772987950923965824595296322935974359005443032824186063805020295740583887005419052788984, 11461948727130534091710429651074304610771753618013831318848441380503003256746662563578377950689405591196133407245233232293704550069947785398827773410578210684, 19339647120384461441994301023611536163314955053297451587025854635525259659171465432658538772709903226258737989321361464364071873250184446438689902191905767679, 119745500799044272063093406220867623200503696575107154044982797016118105232427548630451580061978886344957395474621413026268933193623172609586465513626, 274018657839663542929202860228207469001645755090479587322833754480594651396412074629169877217848610574040200981581423975268426711203399510358745112989, 618229445901538054986587777695206246149508487931910894714739766848714443865470834733227750736328940660288870862490918067505724509269302933712, 1769336435599104274467601578835756732204366611566599170418815541058319836672478073063980540533381739897496152684975359733510915729407748676622, 1641622044523469305097294157141420219383439782972541107245713074215585694324924112344338842325813070829726393724067813488811448638268, 5461155888849876717969459399559421937619795591153212309101576413852340656104944735168597494259557839148913823897825699601314217372890, 2099777785989620075885454815865249869395815123665758202040573458719517509578870012226860600802359690707405503783862004082404, 7683339881576905818107083028556228929898706209448815276838994036300662244192921381739719518265015612165521152679188191674499, 1018318740859495500218933893306511044736394587336478548444509975813715907305277880124606077647932828718523773284106, 3962045045729388803964847102467574132617187525914800210797514547275963785169346875721237550579016448792484761472337], 276093301383168657196256025351596405038123215403309696526860434563991969448157101557511814311364901081645271516973012955084100384181999445583353287700452743296000]]

hecke_ring_character_values = [[11, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [37, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -190, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -7, 0, -24, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 29, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -3379307, 0, -2959, 0, 0, 0, 0, 0, 0, 0, 27, 0, 0, 1, 0], [-564284544, 0, 19, 0, 52, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, -2500817, 0, -13169, 0, 0, 0, 0, 0, 0, 0, 116, 0, 0, -7, -1], [0, -18483, 0, -66133, 0, 0, 0, 488, 162, -11, 0, -503, 0, 0, 0, 0], [-2545288244, 0, 661, 0, 1818, -13, -26, 0, 0, 0, -3, 0, 13, 29, 0, 0], [0, 0, -139177, 0, -9826, 718, 0, 0, 0, 0, 0, 0, -1, 71, 0, 0], [0, -392010, 0, -1392124, 0, 0, 0, -4608, 610, -149, 0, -8960, 0, 0, 0, 0], [0, 0, -122248, 0, -32460, 3578, 0, 0, 0, 0, 0, 0, 270, 290, 0, 0], [0, -3469405227, 0, -3827755, 0, 0, 0, 0, 0, 0, 0, 34208, 0, 0, -1001, 273], [0, 22234855875, 0, 7509753, 0, 0, 0, 0, 0, 0, 0, -67195, 0, 0, 1200, 204], [0, -9242697, 0, -32803816, 0, 0, 0, -134771, 5928, 2402, 0, -211812, 0, 0, 0, 0], [5791442470442, 0, -64352, 0, -181756, 1066, 2132, 0, 0, 0, 3796, 0, -1066, -4318, 0, 0], [0, 0, -16939118, 0, 345380, 132130, 0, 0, 0, 0, 0, 0, -12850, -5110, 0, 0], [0, -67657746, 0, -241553784, 0, 0, 0, 262058, -115400, -12472, 0, -1815200, 0, 0, 0, 0], [0, 0, -7582232, 0, 452206, 252467, 0, 0, 0, 0, 0, 0, 53011, 7479, 0, 0], [33997491118836, 0, -1270423, 0, -3573834, -8255, -16510, 0, 0, 0, -5387, 0, 8255, -22185, 0, 0], [0, -299918311416, 0, 530623200, 0, 0, 0, 0, 0, 0, 0, -4748708, 0, 0, 92136, 572], [0, -359815204, 0, -1281402446, 0, 0, 0, 662656, 1241098, -10549, 0, -8926942, 0, 0, 0, 0], [0, 0, 276947410, 0, 3617824, 988490, 0, 0, 0, 0, 0, 0, -54056, -37184, 0, 0], [0, -581008543, 0, -2076599823, 0, 0, 0, 4588288, -1218708, 156154, 0, -16191493, 0, 0, 0, 0], [0, 0, -184846927, 0, 7024264, -2860156, 0, 0, 0, 0, 0, 0, 79924, -34684, 0, 0], [0, -292344738478, 0, 815915138, 0, 0, 0, 0, 0, 0, 0, -7391816, 0, 0, -215258, 133458], [-415161800108938, 0, -6080692, 0, -16418016, 67912, 135824, 0, 0, 0, -348140, 0, -67912, -44376, 0, 0], [0, 1257187414897, 0, -1858991935, 0, 0, 0, 0, 0, 0, 0, 16949751, 0, 0, 597823, -10624], [0, 0, 4026683, 0, 208085016, 6250860, 0, 0, 0, 0, 0, 0, 1107876, -1283076, 0, 0], [0, 4041182047, 0, 14321750224, 0, 0, 0, 75698581, -6829440, -528090, 0, 87973300, 0, 0, 0, 0], [0, -30057864373937, 0, -7798867829, 0, 0, 0, 0, 0, 0, 0, 70951625, 0, 0, 2459735, -618792], [2201508698580920, 0, -119924151, 0, -338509848, -249570, -499140, 0, 0, 0, 1686191, 0, 249570, -3586910, 0, 0], [0, 16712718793, 0, 59602571639, 0, 0, 0, -832104, 25462762, 2040269, 0, 436331157, 0, 0, 0, 0], [997360602857284, 0, -183120605, 0, -511019530, 180901, 361802, 0, 0, 0, -1009701, 0, -180901, -4252173, 0, 0], [0, 0, -3742754735, 0, 759170002, 133900370, 0, 0, 0, 0, 0, 0, -1819703, -5870447, 0, 0], [0, 0, -11807019706, 0, 1028667808, 40126496, 0, 0, 0, 0, 0, 0, 10068808, -5411168, 0, 0], [0, -186130694542499, 0, -68092146563, 0, 0, 0, 0, 0, 0, 0, 611244576, 0, 0, -8041057, 2280057], [0, 143172159074497, 0, 136849402607, 0, 0, 0, 0, 0, 0, 0, -1234638645, 0, 0, -4839050, -429744], [0, -67028402637, 0, -238536192456, 0, 0, 0, -486125751, -70460392, -7532938, 0, -1651820012, 0, 0, 0, 0], [-3109822631168878, 0, -943358028, 0, -2652023704, -540724, -1081448, 0, 0, 0, 7589332, 0, 540724, -26729268, 0, 0], [0, -124918093534, 0, -444610577944, 0, 0, 0, -22598706, 441435176, 307372, 0, -3051952904, 0, 0, 0, 0], [0, 0, -40417837050, 0, 5009004834, 103751227, 0, 0, 0, 0, 0, 0, 31716429, -29861919, 0, 0], [0, -699096127434337, 0, 465105779033, 0, 0, 0, 0, 0, 0, 0, -4187225215, 0, 0, 14440150, -8331316], [6227723016518484, 0, -1940157983, 0, -5363978314, 9846001, 19692002, 0, 0, 0, -34079363, 0, -9846001, -40685353, 0, 0], [24876277424030616, 0, -1751695957, 0, -4876078576, -4273194, -8546388, 0, 0, 0, -33862539, 0, 4273194, -24075478, 0, 0], [0, 0, -7305229643, 0, 3262433232, -1089699384, 0, 0, 0, 0, 0, 0, -114261888, -46824392, 0, 0], [0, -1602247038751008, 0, 735679224840, 0, 0, 0, 0, 0, 0, 0, -6618221988, 0, 0, 15417096, 17434612], [-56772767812188926, 0, 427036588, 0, 1060697304, -42891628, -85783256, 0, 0, 0, 12423820, 0, 42891628, 41232484, 0, 0], [0, 273023245743907, 0, 403882743979, 0, 0, 0, 0, 0, 0, 0, -3563397875, 0, 0, 231111785, -16172888], [0, 27996330874, 0, 100686471224, 0, 0, 0, -1049657914, -95208296, 36733548, 0, 859448504, 0, 0, 0, 0], [203836311765929890, 0, 5591221680, 0, 15604834420, 36675106, 73350212, 0, 0, 0, 127730484, 0, -36675106, 47934722, 0, 0], [0, -101123843641, 0, -355180712720, 0, 0, 0, -5388889615, 225638648, -183043564, 0, -1475374792, 0, 0, 0, 0], [0, -4100956038757881, 0, -1830462069625, 0, 0, 0, 0, 0, 0, 0, 16456772033, 0, 0, -107625551, 12199888], [0, 96942256207637, 0, -1587392306299, 0, 0, 0, 0, 0, 0, 0, 14214891616, 0, 0, -242367137, -12199471], [0, -271454594321, 0, -957270358831, 0, 0, 0, -1363927512, 6786315878, -123924405, 0, -4402620637, 0, 0, 0, 0], [371634318694797628, 0, 7338724327, 0, 20628700906, -117209937, -234419874, 0, 0, 0, -340383845, 0, 117209937, 444778881, 0, 0], [0, 0, 552004274637, 0, -48900783642, 8807048672, 0, 0, 0, 0, 0, 0, -364821717, 280331707, 0, 0], [0, -1026516080984, 0, -3644256633800, 0, 0, 0, -19490353840, -3254868328, 206226304, 0, -23992218288, 0, 0, 0, 0], [0, 0, -585527635258, 0, -42977061300, -10241247210, 0, 0, 0, 0, 0, 0, 850234410, 483939310, 0, 0], [0, 10203543115906261, 0, 10129889454515, 0, 0, 0, 0, 0, 0, 0, -91213787161, 0, 0, -36224678, 242059904], [0, 0, 599461176452, 0, -125374472680, -7318800148, 0, 0, 0, 0, 0, 0, 98959940, 928589500, 0, 0], [0, -4917469182026, 0, -17560966432136, 0, 0, 0, 33912477666, -2195732696, 512242688, 0, -133117870096, 0, 0, 0, 0], [0, 0, -250980920546, 0, -126273179114, 8155056005, 0, 0, 0, 0, 0, 0, 719562271, 1061021179, 0, 0], [0, 16331039237498205, 0, 13766144876851, 0, 0, 0, 0, 0, 0, 0, -123441025989, 0, 0, 1682759558, 9115884], [-791169530365487144, 0, 7012397875, 0, 22701397280, 376420174, 752840348, 0, 0, 0, -1677255619, 0, -376420174, 652049218, 0, 0], [0, 0, -1561188381044, 0, 44939956674, 5886974521, 0, 0, 0, 0, 0, 0, 276535149, -269543279, 0, 0], [0, 60295814264681002, 0, 36289106942914, 0, 0, 0, 0, 0, 0, 0, -327636257196, 0, 0, -2485769098, 590430366], [-5897205022165952122, 0, -94321846796, 0, -261755262248, 579910500, 1159821000, 0, 0, 0, -601799484, 0, -579910500, -2565115340, 0, 0], [0, -10234794538545217, 0, 19305960303183, 0, 0, 0, 0, 0, 0, 0, -173637438943, 0, 0, 262929201, 822713736], [0, -7488717217468, 0, -26806807746768, 0, 0, 0, 80407658604, -30085550256, 150607520, 0, -216540838496, 0, 0, 0, 0], [0, 0, -1778607922401, 0, 421512623632, 24855229192, 0, 0, 0, 0, 0, 0, 724276192, -2907484712, 0, 0], [0, 0, 2325302357571, 0, 664982191910, 42701260846, 0, 0, 0, 0, 0, 0, -3940790245, -5618292165, 0, 0], [-21222869106709834880, 0, -25546712021, 0, -70122423628, 1215302704, 2430605408, 0, 0, 0, 1662064617, 0, -1215302704, -2461155792, 0, 0], [0, -2740494504015813, 0, -27113093047045, 0, 0, 0, 0, 0, 0, 0, 246976326652, 0, 0, 7546816981, 537043187], [0, -1770218299999, 0, -6384007962163, 0, 0, 0, 17306923504, -44590929448, 1134675696, 0, -63825734833, 0, 0, 0, 0], [0, 0, -203254150033, 0, 430737995260, -95787903103, 0, 0, 0, 0, 0, 0, 2706355510, -2572174210, 0, 0], [0, 2068582547602, 0, 7203886699140, 0, 0, 0, 237334254896, 41660495606, 884968669, 0, 23965889936, 0, 0, 0, 0], [-34524262398058086782, 0, -260242149314, 0, -733647325962, -2100216157, -4200432314, 0, 0, 0, -759414464, 0, 2100216157, -4360148129, 0, 0], [0, -9675043604843, 0, -34413175483312, 0, 0, 0, -33975066293, 32060142296, -5447042848, 0, -229058553984, 0, 0, 0, 0], [16500020781927023374, 0, -29328971048, 0, -70704114964, 3588501982, 7177003964, 0, 0, 0, -1140998684, 0, -3588501982, -3241476586, 0, 0], [0, -13232476119200, 0, -46874373152896, 0, 0, 0, -288740531304, 8073101776, 2905964612, 0, -285970192584, 0, 0, 0, 0], [0, 0, 21422569817390, 0, 448580355260, -81442694868, 0, 0, 0, 0, 0, 0, 16935532670, 185612750, 0, 0], [-44974430949227583132, 0, -218329497595, 0, -631165031850, -2785403735, -5570807470, 0, 0, 0, 10036090105, 0, 2785403735, -7857787065, 0, 0], [0, 166223131811935052, 0, 98444842744500, 0, 0, 0, 0, 0, 0, 0, -884937917004, 0, 0, 2849720868, 4016465336], [0, -7801772211966, 0, -27320394281434, 0, 0, 0, -372773745584, 94157641876, 6898276926, 0, -104581514854, 0, 0, 0, 0], [0, 0, -13713615612146, 0, 324497174084, -213315440752, 0, 0, 0, 0, 0, 0, -1587717286, -2673574334, 0, 0], [0, -57455854424209, 0, -204808186930635, 0, 0, 0, -256196215112, -204131723302, -524623083, 0, -1495071778257, 0, 0, 0, 0], [0, 0, -17264925311225, 0, -105468283992, -174727409452, 0, 0, 0, 0, 0, 0, -3272071452, 100364372, 0, 0], [0, -116680979510329418, 0, 98930803147246, 0, 0, 0, 0, 0, 0, 0, -894400411348, 0, 0, -12204561214, 4301141250], [0, -50698065527102, 0, -181148152697688, 0, 0, 0, 1060114109094, 407616953656, 7402460624, 0, -1357391878544, 0, 0, 0, 0], [0, 0, -10103957222375, 0, -3841991321808, 647874930488, 0, 0, 0, 0, 0, 0, 42864398352, 36537641128, 0, 0], [0, -28705733255353, 0, -100919358113584, 0, 0, 0, -1422206237979, 43410041072, -16763075702, 0, -459429483188, 0, 0, 0, 0], [-109373119316202238104, 0, 1211268743145, 0, 3422455409200, 9364452370, 18728904740, 0, 0, 0, -3902051465, 0, -9364452370, 24175408510, 0, 0], [0, 680929663770097215, 0, -262789346879409, 0, 0, 0, 0, 0, 0, 0, 2376477074128, 0, 0, 26735117229, -604670589], [0, 48943504751609, 0, 176001308749777, 0, 0, 0, -1580833884656, 69294653628, -31323551402, 0, 1574649981123, 0, 0, 0, 0], [0, 265323079119746, 0, 944416884328738, 0, 0, 0, 1273879048352, -16192151136, 8579153268, 0, 6565593881134, 0, 0, 0, 0], [0, 0, -45595862118386, 0, -5987562206592, -767771741360, 0, 0, 0, 0, 0, 0, -52621662312, 32711272912, 0, 0], [40600438904461469818, 0, 666152702452, 0, 1895274688816, -5969568384, -11939136768, 0, 0, 0, -38968261188, 0, 5969568384, 40237874752, 0, 0], [0, 0, -7660770347280, 0, -4989653319764, 498847701238, 0, 0, 0, 0, 0, 0, -38482625294, 28348839214, 0, 0], [0, -778363368490166503, 0, -1436232161642089, 0, 0, 0, 0, 0, 0, 0, 12915231138443, 0, 0, -83000442986, 18981909576], [0, 1207951310838348310, 0, -1016723128357362, 0, 0, 0, 0, 0, 0, 0, 9205471656108, 0, 0, 128286906114, 7752705122], [0, 111756397776318, 0, 400887838901968, 0, 0, 0, -3840054118448, -822872677082, 31415870901, 0, 3267609688948, 0, 0, 0, 0], [65715596930949436504, 0, -244095225469, 0, -685190106832, -14743052010, -29486104020, 0, 0, 0, -32964225091, 0, 14743052010, 22087220490, 0, 0], [0, 0, -8126729901200, 0, 6164587471134, -2013379515821, 0, 0, 0, 0, 0, 0, 120161163339, -20290397809, 0, 0], [0, -280923009218827670, 0, -63784643526294, 0, 0, 0, 0, 0, 0, 0, 591891873784, 0, 0, 58872443142, -11918458358], [0, 1581788471379622793, 0, -1914638770765679, 0, 0, 0, 0, 0, 0, 0, 17225909725279, 0, 0, -76241714653, 12384959152], [0, 264787928809468, 0, 936512048845088, 0, 0, 0, 6522036477740, -717760707696, -76665607396, 0, 5411011127784, 0, 0, 0, 0], [139798336599601219790, 0, -3116729638602, 0, -8708839465306, 10702135307, 21404270614, 0, 0, 0, 9968713400, 0, -10702135307, -91750194841, 0, 0], [0, 0, -14360230149607, 0, 11295877996192, -1941827084048, 0, 0, 0, 0, 0, 0, -215767392608, -125633079632, 0, 0], [0, 0, 43766772203645, 0, 18712596996988, 1944626152471, 0, 0, 0, 0, 0, 0, -109436731682, -157803083218, 0, 0], [0, 385176334353576013, 0, 520040004739213, 0, 0, 0, 0, 0, 0, 0, -4709036778773, 0, 0, -53023154149, -24007327664], [421151949482198286520, 0, -2423692472283, 0, -6609281094424, 16493912246, 32987824492, 0, 0, 0, -109062394733, 0, -16493912246, -22807499718, 0, 0], [-138274316060325761380, 0, -4855915478881, 0, -13698170851518, -8685497093, -17370994186, 0, 0, 0, 64406765659, 0, 8685497093, -144608428131, 0, 0], [0, -818499900646598, 0, -2927677346701630, 0, 0, 0, 7470320628784, -2482593046848, -64042889088, 0, -23129260729018, 0, 0, 0, 0], [0, 0, -210370876067230, 0, 15559529972632, -3411993912900, 0, 0, 0, 0, 0, 0, -61273638548, -125182549652, 0, 0], [0, -1743286225450288933, 0, -1278091966421989, 0, 0, 0, 0, 0, 0, 0, 11734435089848, 0, 0, 633754467889, 12876250791], [0, 10094565115544981575, 0, 1820692403927285, 0, 0, 0, 0, 0, 0, 0, -16324182136767, 0, 0, 201222310984, 39323664028], [0, -679533879035415, 0, -2427795974818104, 0, 0, 0, 11424703234427, 3633168794760, 130405535866, 0, -18316976818420, 0, 0, 0, 0], [-377086812642148340158, 0, -6008079268512, 0, -16673662996556, 15069990754, 30139981508, 0, 0, 0, -88969150972, 0, -15069990754, -120751127142, 0, 0], [0, 0, -29883926229826, 0, 17867183723772, 6504922633084, 0, 0, 0, 0, 0, 0, -418920444498, -214470696882, 0, 0], [0, 1138916038830445013, 0, 3239743398757143, 0, 0, 0, 0, 0, 0, 0, -29455318496069, 0, 0, -857053666332, 102632778300], [0, 12076008957858179562, 0, -3906750808753934, 0, 0, 0, 0, 0, 0, 0, 34875469479108, 0, 0, -900212432146, -50578672274], [-1012372088401906058336, 0, -5011473348641, 0, -14373841227628, -12192758552, -24385517104, 0, 0, 0, 256313439573, 0, 12192758552, -236671872744, 0, 0], [0, 762326838560751, 0, 2729884874931127, 0, 0, 0, -5882363107360, 5518889553484, -67108667998, 0, 22469812389629, 0, 0, 0, 0], [2314931216447647163346, 0, -4517887959232, 0, -12281293288356, 120117230086, 240234460172, 0, 0, 0, -27053961044, 0, -120117230086, -202196213058, 0, 0], [0, 1587566608607428, 0, 5647593168520528, 0, 0, 0, 14061384203916, 2215294876016, -277609003680, 0, 39035320426336, 0, 0, 0, 0], [0, 0, -1114419732795139, 0, -39476940642936, 7316405918500, 0, 0, 0, 0, 0, 0, -452120736516, 194330145076, 0, 0], [0, 0, 248523322705411, 0, -33649448687922, -8906375465870, 0, 0, 0, 0, 0, 0, 1173309096303, 481899299887, 0, 0], [665923139123243181320, 0, 19420231332485, 0, 54608025160480, 8386434818, 16772869636, 0, 0, 0, -173246176693, 0, -8386434818, 560669247646, 0, 0], [0, 28943963926955756105, 0, -4633027774687319, 0, 0, 0, 0, 0, 0, 0, 41825194573988, 0, 0, 156470248679, 134183465761], [-587860529344899610180, 0, 13696213407345, 0, 39031707187490, -19455039457, -38910078914, 0, 0, 0, -613986464503, 0, 19455039457, 650585689361, 0, 0], [0, 0, 163536893697537, 0, -94194156246598, -5536393563978, 0, 0, 0, 0, 0, 0, 1153969794677, 916705148533, 0, 0], [0, -133194362890562, 0, -524450696360742, 0, 0, 0, 41856221460896, -7676594905724, 218484549210, 0, -13576394863554, 0, 0, 0, 0], [439197609898809234954, 0, 39701662185126, 0, 111110291860778, 3843875285, 7687750570, 0, 0, 0, 54270923644, 0, -3843875285, 963495571905, 0, 0], [0, 50129461897336051775, 0, -2804803787529791, 0, 0, 0, 0, 0, 0, 0, 25209955730281, 0, 0, -167211312982, -5358206492], [0, 0, -805411957737130, 0, -66970463392376, -4790253806380, 0, 0, 0, 0, 0, 0, -1479672363356, 185069834916, 0, 0], [0, -33719177557244444805, 0, 10896256938418413, 0, 0, 0, 0, 0, 0, 0, -97226444919699, 0, 0, 2565786960678, 245246215780], [0, -2830287341155082, 0, -10149848501624942, 0, 0, 0, 42933439818752, -16317061723852, 75614213626, 0, -85747514095242, 0, 0, 0, 0], [-158779406273011824992, 0, 29343319304071, 0, 84080483038868, 454977615736, 909955231472, 0, 0, 0, -537709719507, 0, -454977615736, 602264125992, 0, 0], [0, -12399103372811405, 0, -44177340721585423, 0, 0, 0, -11080201670680, 3279437014522, -563618621487, 0, -314612599538053, 0, 0, 0, 0], [0, 0, 833638151034175, 0, -19356466550200, 44760271927716, 0, 0, 0, 0, 0, 0, -1793758860100, -223686822700, 0, 0], [0, -56230351093776436292, 0, 1774332864291404, 0, 0, 0, 0, 0, 0, 0, -16136627847744, 0, 0, -546553852532, 145785910668], [-196573676865538073034, 0, -1183636878112, 0, -4528517294516, -812386979554, -1624773959108, 0, 0, 0, -883624589124, 0, 812386979554, 1080659690502, 0, 0], [0, -8596466170205376, 0, -30649912433708784, 0, 0, 0, 18024609983936, 4771456370256, -499800472184, 0, -221861864095504, 0, 0, 0, 0], [0, 0, -3268029206330315, 0, 6281596971872, -32184071412007, 0, 0, 0, 0, 0, 0, -1807789396648, -412316667232, 0, 0], [0, -33961657409760750943, 0, 33009744811033685, 0, 0, 0, 0, 0, 0, 0, -297575342911265, 0, 0, -274151292095, -396314926560], [-147834266658205323680, 0, -58541225419777, 0, -163793014673356, 128730719544, 257461439088, 0, 0, 0, 198357927253, 0, -128730719544, -1667171762552, 0, 0], [0, 99360705343126020715, 0, -8348822245940597, 0, 0, 0, 0, 0, 0, 0, 75777355437480, 0, 0, 1529039941025, 161507031879], [0, 0, 3215127260850985, 0, 231395131437014, -12383375770940, 0, 0, 0, 0, 0, 0, -446501094781, -1767370739789, 0, 0], [0, 2894291861119592, 0, 10372214448737654, 0, 0, 0, -32727239692592, 17934032083834, 1745191267367, 0, 85348766558454, 0, 0, 0, 0], [0, 0, 812719510446002, 0, 29956825652008, 26187999781764, 0, 0, 0, 0, 0, 0, -391026171212, -296417090188, 0, 0], [0, -35212349588145620603, 0, -12347681209219467, 0, 0, 0, 0, 0, 0, 0, 110726943291488, 0, 0, -901203990801, -842398230143], [0, 0, -3927586581122772, 0, 213361516218404, -70785885873134, 0, 0, 0, 0, 0, 0, -273818707546, -1601655362534, 0, 0], [0, 7339868624465960, 0, 26025844655322192, 0, 0, 0, 123726512306752, -13452844920064, 1148201262900, 0, 161039098311576, 0, 0, 0, 0], [-10478106474528152943372, 0, 13888172727387, 0, 40722443287086, 909425324769, 1818850649538, 0, 0, 0, 592359382459, 0, -909425324769, -707177914537, 0, 0], [0, 1501150493979278, 0, 5187873102115194, 0, 0, 0, 197980731470688, 19467991205076, -524109444094, 0, 9660384883486, 0, 0, 0, 0], [0, 0, 7113912464672980, 0, 243158860532120, 31545841489072, 0, 0, 0, 0, 0, 0, -2803175886940, -2330781053380, 0, 0], [0, 689868848056839, 0, 2521354927963399, 0, 0, 0, -139377708660720, -50997829385988, -1684625834298, 0, 26397308718277, 0, 0, 0, 0], [0, -21837299539643042394, 0, -2556852706454602, 0, 0, 0, 0, 0, 0, 0, 20205219577216, 0, 0, -7705680225062, -787314253010], [0, 186379106822535345473, 0, 4912339840385381, 0, 0, 0, 0, 0, 0, 0, -42679561396049, 0, 0, 5751255917593, -1616266646096], [0, 0, -6255420151963493, 0, 670262087228328, 69143270062068, 0, 0, 0, 0, 0, 0, -764623782732, -5012112703948, 0, 0], [0, 25536941430713027, 0, 91146326786706800, 0, 0, 0, -72761983384547, 46980709015720, -1665906357664, 0, 684196898290560, 0, 0, 0, 0], [0, -65528415986250612035, 0, -40204894365741903, 0, 0, 0, 0, 0, 0, 0, 363717241735267, 0, 0, 4395679930821, 25319611168], [0, 119353525892846053137, 0, -74203820596106335, 0, 0, 0, 0, 0, 0, 0, 671586845259500, 0, 0, 9235037323375, -318970021855], [10027389869069684251492, 0, -60017010913359, 0, -168219577443682, 2027808042965, 4055616085930, 0, 0, 0, 4874841172149, 0, -2027808042965, -5539611666125, 0, 0], [0, 0, 13468086666896177, 0, -82010013520736, 76120021704309, 0, 0, 0, 0, 0, 0, 2280490140064, 1056983604656, 0, 0]]
